==> rwa_mix_wig-0.0.19.tar.gz: lib/rwa_mix_wig.dart <==
library rwa_mix_wig;
import 'dart:io';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

import 'dart:ui' as ui;
import 'package:path_provider/path_provider.dart';
import 'package:get/get.dart';
RxInt numberToShow = 0.obs;
GlobalKey globalKey = GlobalKey();
/// A Calculator.
class MixWig extends StatefulWidget {
  final Widget? second;
  final List<Widget>? baseList;
  int currentWidget;
  MixWig({this.second,this.baseList,this.currentWidget = 0});
  // This widget is the root of your application.
  @override
  _MixWigState createState() => _MixWigState();
}

void setThisWidget(int num){
  numberToShow.value = num;
}

class _MixWigState extends State<MixWig> {
  double offSetX = 150.0;
  double offSetY = 20.0;
  bool isChildIsSelected = false;
  double newScale = 1.0;
  double previousScale = 1.0;
  String fileName = '';

  Widget? base;
  List<Widget>? baseList;
  Widget? second;
  @override
  void initState() {
    numberToShow.value = widget.currentWidget;
    // TODO: implement initState
    if(widget.second == null){
      second = Container(
        color: Colors.black,
      );
    }else{
      second = widget.second;
    }
    if(widget.baseList == null || widget.baseList?.length ==0){
      base =
      Card(
        child: Container(
          height: 400,
          width: double.infinity,
          color: Colors.blue,
        ),
      );
    }else{
      base = widget.baseList![numberToShow.value];
    }
    super.initState();
  }
  @override
  Widget build(BuildContext context) {
    return _ConvertWidgetToImage(
      key: globalKey,
      builder: (key) =>Stack(
        children: [
          GestureDetector(
            onScaleStart: (data){
              if(isChildIsSelected){
                newScale = previousScale;
              }
            },
            onScaleUpdate: (data) {
              if (isChildIsSelected) {
                newScale = maxScaleIs2(data)?2:(scaleIsLessThanHalf(data)?1/2:newScale+ (data.scale-1)/10);
                previousScale = newScale;
                setState(() {

                });
              }

            },
            onHorizontalDragStart: (data) {
              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            onHorizontalDragUpdate: (data) {
              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            child: Obx(() {
                return widget.baseList![numberToShow.value];
              }
            ),
          ),
          Positioned(
            left: offSetX -( 85)*newScale,
            top: offSetY -( 85)*newScale,
            child: GestureDetector(
              onTap: () {
                isChildIsSelected = !isChildIsSelected;
                setState(() {

                });
              },
              child: Container(
                color: Colors.transparent,
                child: Column(
                  children: [
                    Container(
                      decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: isChildIsSelected
                              ? Colors.white54
                              : Colors.transparent),
                      height: 110 * newScale,
                      width: 110 * newScale,
                      alignment: Alignment.center,
                      child: Container(
                        decoration: BoxDecoration(
                            shape: BoxShape.circle, color: Colors.transparent),
                        height: 90 * newScale,
                        width: 90 * newScale,
                        child: second,
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  bool scaleIsLessThanHalf(ScaleUpdateDetails data) => newScale+ (data.scale-1)/10<.5;

  bool maxScaleIs2(ScaleUpdateDetails data) => newScale+ (data.scale-1)/10>2;
}
Future capture() async {


  RenderRepaintBoundary? boundary = globalkey.currentContext!.findRenderObject() as RenderRepaintBoundary?;
  final image = await boundary!.toImage(pixelRatio: 3);
  final byteData = await image.toByteData(format: ui.ImageByteFormat.png);
  final pngBytes = byteData!.buffer.asUint8List();

  final directory = await getApplicationDocumentsDirectory();
  final pathOfImage = await File('${directory.path}/user_avatar.png').create();
  await pathOfImage.writeAsBytes(pngBytes);
  return pathOfImage; }
class _ConvertWidgetToImage extends StatefulWidget {
  final Function(GlobalKey key) builder;

  const _ConvertWidgetToImage({
    required this.builder,
    required Key key,
  }) : super(key: key);

  @override
  _ConvertWidgetToImageState createState() => _ConvertWidgetToImageState();
}
class _ConvertWidgetToImageState extends State<_ConvertWidgetToImage> {
  final globalKey = GlobalKey();

  @override
  Widget build(BuildContext context) {
    return RepaintBoundary(
      key: globalKey,
      child: widget.builder(globalKey),
    );
  }
}

==> rwa_mix_wig-0.0.31.tar.gz: lib/rwa_mix_wig.dart <==
library rwa_mix_wig;
import 'dart:io';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'dart:math';

import 'dart:ui' as ui;
import 'package:path_provider/path_provider.dart';
import 'package:get/get.dart';
RxInt numberToShow = 0.obs;
GlobalKey globalKey = GlobalKey();
/// A Calculator.
class MixWig extends StatefulWidget {
  final Widget? second;
  final List<Widget>? baseList;
  int currentWidget;
  MixWig({this.second,this.baseList,this.currentWidget = 0});
  // This widget is the root of your application.
  @override
  _MixWigState createState() => _MixWigState();
}

void setThisWidget(int num){
  numberToShow.value = num;
}

class _MixWigState extends State<MixWig> {
  double offSetX = 150.0;
  double offSetY = 50.0;
  bool isChildIsSelected = false;
  double newScale = 1.0;
  double previousScale = 1.0;
  String fileName = '';

  Widget? base;
  List<Widget>? baseList;
  Widget? second;
  int dragOnSmall = 1;

  @override
  void initState() {
    numberToShow.value = widget.currentWidget;
    // TODO: implement initState
    if(widget.second == null){
      second = Container(
        color: Colors.black,
      );
    }else{
      second = widget.second;
    }
    if(widget.baseList == null || widget.baseList?.length ==0){
      base =
          Card(
            child: Container(
              height: 400,
              width: double.infinity,
              color: Colors.blue,
            ),
          );
    }else{
      base = widget.baseList![numberToShow.value];
    }
    super.initState();
  }
  @override
  Widget build(BuildContext context) {
    return _ConvertWidgetToImage(
      key: globalKey,
      builder: (key) =>Stack(
        children: [
          isChildIsSelected?GestureDetector(
            onScaleStart: (data){
              dragOnSmall = 1;

              if(isChildIsSelected){
                newScale = previousScale;
              }
            },
            onScaleUpdate: (data) {
              dragOnSmall = 1;

              if (isChildIsSelected) {
                newScale = maxScaleIs2(data)?2:(scaleIsLessThanHalf(data)?1/2:newScale+ (data.scale-1)/10);
                previousScale = newScale;
                setState(() {

                });
              }
            },

            child: Obx(() {
              return widget.baseList![numberToShow.value];
            }
            ),
          ):GestureDetector(

            onTapUp: (data){
              dragOnSmall = 1;

              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            onVerticalDragStart: (data){
              dragOnSmall = 1;

              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            onVerticalDragUpdate: (data){
              dragOnSmall = 1;

              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            onHorizontalDragStart: (data) {
              dragOnSmall = 1;

              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            onHorizontalDragUpdate: (data) {
              dragOnSmall = 1;

              if (!isChildIsSelected) {
                offSetX = data.localPosition.dx;
                offSetY = data.localPosition.dy;
              }
              setState(() {

              });
            },
            child: Obx(() {
              return widget.baseList![numberToShow.value];
            }
            ),
          ),
          Positioned(
            left: offSetX -(( 85)*newScale)*dragOnSmall,
            top: offSetY -(( 85)*newScale)*dragOnSmall,
            child: GestureDetector(
              onTap: () {
                isChildIsSelected = !isChildIsSelected;
                setState(() {

                });
              },
              onVerticalDragStart: (data){
                dragOnSmall = 0;
                if (!isChildIsSelected) {
                  offSetX = data.localPosition.dx;
                  offSetY = data.localPosition.dy;
                }
                setState(() {

                });
              },
              onVerticalDragUpdate: (data){
                dragOnSmall = 0;

                if (!isChildIsSelected) {
                  offSetX = data.localPosition.dx;
                  offSetY = data.localPosition.dy;
                }
                setState(() {

                });
              },
              onHorizontalDragStart: (data) {
                dragOnSmall = 0;

                if (!isChildIsSelected) {
                  offSetX = data.localPosition.dx;
                  offSetY = data.localPosition.dy;
                }
                setState(() {

                });
              },
              onHorizontalDragUpdate: (data) {
                dragOnSmall = 0;

                if (!isChildIsSelected) {
                  offSetX = data.localPosition.dx;
                  offSetY = data.localPosition.dy;
                }
                setState(() {

                });
              },
              child: Container(
                color: Colors.transparent,
                child: Column(
                  children: [
                    Container(
                      decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: isChildIsSelected
                              ? Colors.white54
                              : Colors.transparent),
                      height: 110 * newScale,
                      width: 110 * newScale,
                      alignment: Alignment.center,
                      child: Container(
                        decoration: BoxDecoration(
                            shape: BoxShape.circle, color: Colors.transparent),
                        height: 90 * newScale,
                        width: 90 * newScale,
                        child: second,
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  bool scaleIsLessThanHalf(ScaleUpdateDetails data) => newScale+ (data.scale-1)/10<.5;

  bool maxScaleIs2(ScaleUpdateDetails data) => newScale+ (data.scale-1)/10>2;
}
Future capture({String? fileName}) async {
  const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
  Random _rnd = Random();

  String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
      length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));

  if(fileName == null){
    fileName = getRandomString(15);
  }

  RenderRepaintBoundary? boundary = globalKey.currentContext!.findRenderObject() as RenderRepaintBoundary?;
  final image = await boundary!.toImage(pixelRatio: 3);
  final byteData = await image.toByteData(format: ui.ImageByteFormat.png);
  final pngBytes = byteData!.buffer.asUint8List();

  final directory = await getApplicationDocumentsDirectory();
  final pathOfImage = await File('${directory.path}/${fileName}.png').create();
  await pathOfImage.writeAsBytes(pngBytes);
  return pathOfImage; }
class _ConvertWidgetToImage extends StatefulWidget {
  final Function(GlobalKey key) builder;

  const _ConvertWidgetToImage({
    required this.builder,
    required Key key,
  }) : super(key: key);

  @override
  _ConvertWidgetToImageState createState() => _ConvertWidgetToImageState();
}
class _ConvertWidgetToImageState extends State<_ConvertWidgetToImage> {
  final globalKey = GlobalKey();

  @override
  Widget build(BuildContext context) {
    return RepaintBoundary(
      key: globalKey,
      child: widget.builder(globalKey),
    );
  }
}
